==> audio_clips-1.0.0.zip: audio_clips/src/FFMpeg/AudioFile.php <==
<?php

namespace Drupal\audio_clips\FFMpeg;

/**
 * AudioFile Class.
 *
 * Use FFMpeg to clip audio and FFProbe to get file infos.
 */
class AudioFile {

  /**
   * The AudioFile path.
   *
   * @var string
   */
  public string $path;

  /**
   * Constructs the service.
   *
   * @param string $path
   *   The audio file path.
   */
  public function __construct(string $path) {
    if (!file_exists($path)) {
      throw new \InvalidArgumentException("File not found : $path");
    }

    $this->path = $path;
  }

  /**
   * Clip Audio and save clip in new audio file.
   *
   * @param int $start_time
   *   The start time in seconds.
   * @param int $end_time
   *   The end time in seconds.
   * @param string $output_path
   *   The destination path.
   *
   * @return int
   *   Return status code of the shell command.
   */
  public function processClipAudio(int $start_time, int $end_time, $output_path): int {
    // -y to replace file if already exist
    // @todo make it cleaner
    $command = "ffmpeg -y -i " . escapeshellarg($this->path) .
     " -ss {$start_time} -to {$end_time} -c copy " . escapeshellarg($output_path);

    $return_code = 0;
    $output = [];
    exec($command, $output, $return_code);
    return $return_code;
  }

  /**
   * Get audio duration time in sec.
   *
   * @return float
   *   Return audio duration value.
   */
  public function getAudioDuration(): float {
    $command = "ffprobe -i " . escapeshellarg($this->path) . " -show_entries format=duration -v quiet -of csv='p=0'";
    $duration = shell_exec($command);
    return (float) $duration;
  }

  /**
   * Get audio file format.
   *
   * @return string
   *   Return audio file format.
   */
  public function getAudioFormat(): string {
    $command = "ffprobe -i " . escapeshellarg($this->path) . " -show_entries format=format_name -v quiet -of csv='p=0'";
    $format = shell_exec($command);
    return str_replace("\n", "", $format);
  }

}

==> audio_clips-1.0.3.zip: audio_clips/src/FFMpeg/AudioFile.php <==
<?php

namespace Drupal\audio_clips\FFMpeg;

use Drupal\Core\File\FileExists;
use Drupal\Core\File\FileSystemInterface;

/**
 * AudioFile Class.
 *
 * Use FFProbe to get file infos.
 */
class AudioFile {

  /**
   * The AudioFile path.
   *
   * @var string
   */
  public string $path;

  /**
   * Constructs the service.
   *
   * @param string $path
   *   The audio file path.
   */
  public function __construct(string $path) {
    if (!file_exists($path)) {
      throw new \InvalidArgumentException("File not found : $path");
    }
    $this->path = $path;
  }

  /**
   * Build file output path and process crop.
   *
   * @param int $start_time
   *   The start time in seconds.
   * @param int $end_time
   *   The end time in seconds.
   * @param string $clip_name
   *   The clip name path.
   *
   * @return string
   *   Return clip file path.
   */
  public function buildClipAudio(int $start_time, int $end_time, string $clip_name): string {
    $file_system = \Drupal::service('file_system');
    $directory_target = 'public://audio_clip/clip_' . $clip_name . '/public/' . date('Y-m');
    $file_system->prepareDirectory($directory_target, FileSystemInterface::CREATE_DIRECTORY);
    $file_path = $file_system->getDestinationFilename($directory_target . '/' . basename($this->path), FileExists::Replace);
    $output_path = $file_system->realpath($file_path);

    $return_code = $this->processClipAudio($start_time, $end_time, $output_path);
    if ($return_code !== 0) {
      throw new \RuntimeException("Error ffmpeg : " . $return_code);
    }

    return $output_path;
  }

  /**
   * Clip Audio and save clip in new audio file.
   *
   * @param int $start_time
   *   The start time in seconds.
   * @param int $end_time
   *   The end time in seconds.
   * @param string $output_path
   *   The destination path.
   *
   * @return int
   *   Return status code of the shell command.
   */
  private function processClipAudio(int $start_time, int $end_time, string $output_path): int {
    // -y to replace file if already exist
    // @todo make it cleaner
    $command = "ffmpeg -y -i " . escapeshellarg($this->path) .
     " -ss {$start_time} -to {$end_time} -c copy " . escapeshellarg($output_path);

    $return_code = 0;
    $output = [];
    exec($command, $output, $return_code);
    return $return_code;
  }

  /**
   * Get audio duration time in sec.
   *
   * @return float
   *   Return audio duration value.
   */
  public function getAudioDuration(): float {
    $command = "ffprobe -i " . escapeshellarg($this->path) . " -show_entries format=duration -v quiet -of csv='p=0'";
    $duration = shell_exec($command);
    return (float) $duration;
  }

  /**
   * Get audio file format.
   *
   * @return string
   *   Return audio file format.
   */
  public function getAudioFormat(): string {
    $command = "ffprobe -i " . escapeshellarg($this->path) . " -show_entries format=format_name -v quiet -of csv='p=0'";
    $format = shell_exec($command);
    return str_replace("\n", "", $format);
  }

}
